;;;; -*- Mode: Lisp; Syntax: ANSI-Common-Lisp; Base: 10 -*-
;;;; *************************************************************************
;;;; FILE IDENTIFICATION
;;;;
;;;; Name:          package.lisp
;;;; Purpose:       Package definition for kmrcl package
;;;; Programmer:    Kevin M. Rosenberg
;;;; Date Started:  Apr 2000
;;;;
;;;; $Id: package.lisp,v 1.48 2003/07/09 19:19:19 kevin Exp $
;;;;
;;;; This file, part of KMRCL, is Copyright (c) 2002 by Kevin M. Rosenberg
;;;;
;;;; KMRCL users are granted the rights to distribute and use this software
;;;; as governed by the terms of the Lisp Lesser GNU Public License
;;;; (http://opensource.franz.com/preamble.html), also known as the LLGPL.
;;;; *************************************************************************

(in-package #:cl-user)

(defpackage #:kmrcl
  (:nicknames #:kl)
  (:use #:cl)
  (:export
   #:ensure-integer
   #:mklist
   #:filter
   #:appendnew
   #:memo-proc
   #:memoize
   #:defun-memo
   #:_f
   #:compose
   #:until
   #:while
   #:for

   ;; strings.lisp
   #:mapappend
   #:mapcar-append-string
   #:mapcar2-append-string
   #:position-char
   #:position-not-char
   #:delimited-string-to-list
   #:string-delimited-string-to-list
   #:list-to-delimited-string
   #:prefixed-fixnum-string
   #:integer-string
   #:fast-string-search
   #:string-to-list-skip-delimiter
   #:string-starts-with
   #:count-string-char
   #:count-string-char-if
   #:hexchar
   #:escape-uri-field
   #:unescape-uri-field
   #:non-alphanumericp
   #:random-string
   #:first-char
   #:last-char
   #:ensure-string
   #:string-right-trim-one-char
   
   #:flatten

   ;; io.lisp
   #:indent-spaces
   #:indent-html-spaces
   #:print-n-chars
   #:print-n-strings
   #:print-list
   #:print-rows
   #:write-fixnum
   #:file-subst
   #:stream-subst

   ;; lists.lisp
   #:remove-tree-if
   #:find-tree
   #:with-each-file-line
   #:with-each-stream-line
   #:remove-keyword
   #:remove-keywords
   #:append-sublists
   #:alist-elem-p
   #:alistp
   #:get-alist
   #:update-alist
   #:alist-plist
   #:plist-alist
   #:update-plist
   #:get-plist

   ;; seq.lisp
   #:nsubseq
   
   ;; math.lisp
   #:ensure-integer
   
   ;; macros.lisp
   #:time-iterations
   #:in
   #:mean
   #:with-gensyms
   #:let-if
   #:let-when
   #:aif
   #:awhen
   #:awhile
   #:aand
   #:acond
   #:alambda
   #:it
   #:mac
   
   ;; files.lisp
   #:print-file-contents
   #:read-file-to-string
   #:read-file-to-strings
   
   ;; strings.lisp
   #:string-append
   #:count-string-words
   #:substitute-string-for-char
   #:string-trim-last-character
   #:nstring-trim-last-character
   #:string-hash
   #:string-not-null?
   #:whitespace?
   #:not-whitespace?
   #:string-ws?
   #:string-invert
   #:escape-xml-string
   #:make-usb8-array
   #:usb8-array-to-string
   #:string-to-usb8-array
   #:substitute-chars-strings
   #:add-sql-quotes
   #:escape-backslashes
   #:concat-separated-strings
   #:print-separated-strings
   
   ;; symbols.lisp
   #:ensure-keyword
   #:concat-symbol
   #:concat-symbol-pkg
   #:show
   #:show-variables
   #:show-functions
   
   ;; From attrib-class.lisp
   #:attributes-class
   #:slot-attribute
   #:slot-attributes

   #:generalized-equal

   ;; From buffered input
   
   #:make-fields-buffer
   #:read-buffered-fields
   
   ;; From datetime.lisp
   #:pretty-date
   #:date-string
   #:print-float-units
   #:print-seconds
   
   ;; From random.lisp
   #:seed-random-generator
   #:random-choice
   
   ;; From telnet-server.lisp
   #:start-telnet-server	  
   
   ;; From web-utils
   #:*base-url*
   #:base-url!
   #:make-url
   #:*standard-html-header*
   #:*standard-xhtml-header*
   #:*standard-xml-header*
   #:user-agent-ie-p
   #:decode-uri-query-string
   
   ;; From xml-utils
   #:wrap-with-xml
   #:xml-tag-contents
   #:positions-xml-tag-contents
   #:xml-cdata
   #:write-xml-cdata
   
   ;; From console
   #:*console-msgs*
   #:cmsg
   #:cmsg-c
   #:cmsg-add
   #:cmsg-remove
   #:fixme

   ;; byte-stream
   #:make-binary-array-output-stream
   #:get-output-stream-data
   #:dump-output-stream-data
   #:make-byte-array-input-stream

   ;; sockets.lisp
   #:make-active-socket
   #:close-active-socket
   
   ;; listener.lisp
   #:init/listener
   #:stop-all/listener
   #:listener
   ))



